@@ -241,7 +241,11 @@ dialog_contents (void)
 
   vbox = gtk_vbox_new (FALSE, 0);
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+  action_area = gtk_button_box_new (GTK_ORIENTATION_HORIZONTAL);
+#else
   action_area = gtk_hbutton_box_new ();
+#endif
 
   gtk_button_box_set_layout (GTK_BUTTON_BOX (action_area),
                              GTK_BUTTONBOX_END);
@@ -346,7 +350,12 @@ menu_contents (void)
     {
       char *str = g_strdup_printf (_("Fake menu item %d\n"), i + 1);
       mi = gtk_label_new (str);
+#if GTK_CHECK_VERSION (3, 0, 0)
+      gtk_widget_set_halign (image, GTK_ALIGN_START);
+      gtk_widget_set_valign (image, GTK_ALIGN_CENTER);
+#else
       gtk_misc_set_alignment (GTK_MISC (mi), 0.0, 0.5);
+#endif
       g_free (str);
       gtk_box_pack_start (GTK_BOX (vbox), mi, FALSE, FALSE, 0);
 
